(guides)=
# Guides to elevated analysis

This section is a collection of guides gathering background knowledge related to elevation data to help grasp how to best
elevate your analysis!

```{toctree}
:maxdepth: 2

elevation_intricacies
static_surfaces
accuracy_precision
robust_estimators
spatial_stats
```
